@@ -413,25 +413,6 @@ class TestManager:
         assert 'Development' in out
         assert 'OK' in out
 
-        code = run('manage.py -c Before simple', lambda: manager.run())
-        out, err = capsys.readouterr()
-        assert code == 0
-        assert 'Before' in out
-        assert 'OK' in out
-
-        code = run('manage.py simple -c After', lambda: manager.run())
-        out, err = capsys.readouterr()
-        assert code == 0
-        assert 'After' in out
-        assert 'OK' in out
-
-        code = run('manage.py -c DoNotShow simple -c NewValue', lambda: manager.run())
-        out, err = capsys.readouterr()
-        assert code == 0
-        assert 'DoNotShow' not in out  # first parameter is ignored
-        assert 'NewValue' in out       # second on is printed
-        assert 'OK' in out
-
     def test_get_usage(self):
 
         manager = Manager(self.app)
@@ -492,12 +473,15 @@ class TestManager:
         assert code == 2
         assert 'OK' not in out
 
-    def test_run_no_name(self):
+    def test_run_no_name(self, capsys):
 
         manager = Manager(self.app)
+        manager.add_command('simple', SimpleCommand())
 
         code = run('manage.py', lambda: manager.run())
+        out, err = capsys.readouterr()
         assert code == 2
+        assert 'simple command' in out
 
     def test_run_good_options(self, capsys):
 
@@ -734,7 +718,10 @@ class TestSubManager:
         code = run('manage.py sub_manager', lambda: manager.run())
         out, err = capsys.readouterr()
         assert code == 2
-        assert 'too few arguments' in err
+        assert 'sub_manager [--foo]' in out
+        assert 'shorter desc for submanager' not in out
+        assert 'longer desc for submanager' in out
+        assert 'simple command' in out
 
         code = run('manage.py sub_manager -h', lambda: manager.run())
         out, err = capsys.readouterr()
